Computes the information matrix (C-matrix) for treatment effects under either the linear fixed effects model or the linear mixed effects model setting for a given row-column design.
Usage
cmatrcd.mae(trt.N, col.N, theta, des)
Arguments
trt.N
integer, specifying number of treatments, v.
col.N
integer, specifying number of arrays (columns), b.
theta
numeric, representing a function of the ratio of random array variance and random error variance. It takes any value between 0 and 1, inclusive.
des
matrix, a 2 x b row-column design with b arrays/columns of size k = 2 and v treatments.
Value
Returns a v x v treatment information matrix (C-matrix).
References
Debusho, L. K., Gemechu, D. B., and Haines, L. M. (2016). Algorithmic construction of optimal block designs for two-colour cDNA microarray experiments using the linear mixed model. Under review. Gemechu, D. B., Debusho, L. K., and Haines, L. M. (2015). A-and D-optional row-column designs for two-colour cDNA microarray experiments using linear mixed effects models. South African Statistical Journal, 49, 153-168.