Learn R Programming

optrcdmaeAT (version 1.0.0)

intcrcd.mae:

Description

Generates a random initial connected row-column design for a given number of arrays b of size k = 2 and the number of treatments v.

Usage

intcrcd.mae(trt.N, col.N)

Arguments

trt.N
integer, specifying number of treatments, v.
col.N
integer, specifying number of arrays, b.

Value

Returns a 2 x b connected row-column design with b arrays of size k = 2 and number of treatments v.

References

Debusho, L. K., Gemechu, D. B., and Haines, L. M. (2016). Algorithmic construction of optimal block designs for two-colour cDNA microarray experiments using the linear mixed model. Under review. Gemechu, D. B., Debusho, L. K., and Haines, L. M. (2014). A-optimal designs for two-colour cDNA microarray experiments using the linear mixed effects model. Peer-reviewed Proceedings of the Annual Conference of the South African Statistical Association for 2014 (SASA 2014), Rhodes University, Grahamstown, South Africa. pp 33-40, ISBN: 978-1-86822-659-7. Gemechu, D. B., Debusho, L. K., and Haines, L. M. (2015). A-and D-optional row-column designs for two-colour cDNA microarray experiments using linear mixed effects models. South African Statistical Journal, 49, 153-168.

See Also

optrcdmaeAT, cmatrcd.mae

Examples

Run this code
    #Initial connected row-column design for 
    trt.N <- 4 #Number of treatments
    col.N <- 4 #Number of arrays

    intcrcd.mae(trt.N = 4, col.N = 4)

Run the code above in your browser using DataLab