Learn R Programming

optrcdmaeAT (version 1.0.0)

mmenurcd.mae:

Description

Alternative to directly using the function optrcdmaeAT on the R console, the function mmenurcd.mae creates the main menu tcltk window with the list of four optimality criteria (A, MV, D and E) for search of optimal or near-optimal row-column designs for two-colour cDNA microarray experiments.

Usage

mmenurcd.mae()

Arguments

Details

The main menu window created using the function mmenurcd.mae contains the list of four optimality criteria (the A-, MV -, D- and E) for row-column designs that allows user to choose an optimality criterion of interest. The function will then call for a function fixparrcd.mae for further option regarding the setup of parametric combinations and output, see fixparrcd.mae documentation.

See Also

optrcdmaeAT, fixparrcd.mae, tcltk, TkWidgets